==> haskell-persistent-sqlite-2.9.3-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.9.3
id: persistent-sqlite-2.9.3-HqorgVNR4mM8f7WMBOVq9P
key: persistent-sqlite-2.9.3-HqorgVNR4mM8f7WMBOVq9P
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
abi: 9b6ffea288658c7d4e2ebc67e1c2928c
exposed: True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-sqlite-2.9.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-sqlite-2.9.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-sqlite-2.9.3
hs-libraries: HSpersistent-sqlite-2.9.3-HqorgVNR4mM8f7WMBOVq9P
extra-libraries:
    pthread sqlite3
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-Jmotk7FVIoVB29sd5GQrbo
    containers-0.6.0.1 microlens-th-0.4.2.3-2ty2TK3jSO111y1tN2Ao3p
    monad-logger-0.3.30-DEMTYPqThZT7F1IvTj1veL
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    persistent-2.9.2-4GhmUaEkDKCxpLU7R96Iz
    resource-pool-0.2.3.2-8cgGaZ1cXHR8Of69rZeZhx
    resourcet-1.2.2-1jEybJ3raWeJ8zv1YiemYn text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.9.3-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.9.3
id: persistent-sqlite-2.9.3-3IT0MAzOCPfHKMvqYlF5OO
key: persistent-sqlite-2.9.3-3IT0MAzOCPfHKMvqYlF5OO
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
abi: 93993abfff57424dbb6d50a62c0a6b0b
exposed: True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-sqlite-2.9.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-sqlite-2.9.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-sqlite-2.9.3
hs-libraries: HSpersistent-sqlite-2.9.3-3IT0MAzOCPfHKMvqYlF5OO
extra-libraries:
    pthread sqlite3
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-Jmotk7FVIoVB29sd5GQrbo
    containers-0.6.0.1 microlens-th-0.4.2.3-2ty2TK3jSO111y1tN2Ao3p
    monad-logger-0.3.30-G9tqumVWGCM57eJKfvrWj2
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    persistent-2.9.2-3u5sEeMdF1j1hV35HLaWMf
    resource-pool-0.2.3.2-8cgGaZ1cXHR8Of69rZeZhx
    resourcet-1.2.2-1jEybJ3raWeJ8zv1YiemYn text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
